function input(){
	f=openRead(inFileName);
	K = readInt(f);
	lb = readInt(f);
	ub = readInt(f);
	r[1..K] = readInt(f);
	d[1..K] = readInt(f);
	beta[1..K] = readInt(f);	
	totalDemand = sum[i in 1..K] (r[i]);
	maxDemand = max[i in 1..K] (r[i]);
	maxBatches = lb > 0 ? 2*ceil(totalDemand / (lb + 0.0)) : totalDemand;	
	println("nbVar:" + maxBatches * K * maxDemand);
}


function model(){
	for[k in 1..K]{
		for[b in 1..maxBatches]
			for[i in 1..maxDemand]
				x[k][b][i] <- bool(); //i-th element of customer k is in batch b
			
		//meet the request
		constraint sum[b in 1..maxBatches][i in 1..maxDemand] (x[k][b][i]) == r[k];
	}
	
	//batch size
	for [b in 1..maxBatches]{
		size[b] <- sum[k in 1..K][i in 1..maxDemand] (x[k][b][i]);
		constraint size[b] <= ub;		
	}
	
	//starting & completion time of each batch
	s[1] <- 0;
	c[1] <- size[1];
	for [b in 2..maxBatches]{
		s[b] <- c[b-1];
		c[b] <- s[b] + size[b];
	}
	
	for[k in 1..K][b in 1..maxBatches]{
		q[k][b] <- sum[i in 1..maxDemand] (x[k][b][i]);
		//completionTime[k][b] <- q[k][b] > 0 ? c[b] : 0;
		//T[k][b] <- completionTime[k][b] > d[k] ? completionTime[k][b] - d[k] : 0;
		
		T[k][b] <- q[k][b] > 0 && c[b] > d[k] ? c[b] - d[k] : 0;
	}
	minimize sum[b in 1..maxBatches](size[b]*max(0,(lb - size[b])));
	minimize sum[k in 1..K][b in 1..maxBatches](T[k][b]*q[k][b]*beta[k]);
}

function param(){
	//for[i in 1..23] setValue(x[1][5][i],1);
	//for[i in 1..8] 	setValue(x[2][5][i],1);
	//for[i in 1..12] setValue(x[3][2][i],1);
	//for[i in 1..9] 	setValue(x[4][6][i],1);
	//for[i in 1..18] setValue(x[5][6][i],1);
	//for[i in 1..15] setValue(x[6][2][i],1);
	//for[i in 1..23] setValue(x[7][7][i],1);
	//for[i in 1..7] 	setValue(x[8][7][i],1);
	//for[i in 1..30] setValue(x[9][3][i],1);
	//for[i in 1..27] setValue(x[10][8][i],1);
	
	setObjectiveBound(0,0);
	if(lsTimeLimit==nil) lsTimeLimit=5;
}

function output(){
	for[k in 1..K]{
		print("customer "+ k + ":\t");
		for[b in 1..maxBatches]{
			print(getValue(q[k][b])+ "\t");
		}
		println();
	}
	println();
	for[b in 1..maxBatches]{
		if(getValue(size[b]) > 0)
			println("batch "+ b + ":\t[" + getValue(s[b]) + "\t"+ getValue(c[b]) + "]\t");
	}
}